==> eslint-config-opinionated-1.0.0.tgz: package/index.js <==
/* eslint-disable no-magic-numbers */

module.exports = {

  extends: [
    'eslint:all',
  ],

  plugins: [
    'babel',
    'import',
    'xo',
  ],

  parser: 'babel-eslint',
  parserOptions: {
    ecmaVersion: 7,
    sourceType: 'module',
    ecmaFeatures: {
      globalReturn: false,
      impliedStrict: true,
      jsx: true,
      experimentalObjectRestSpread: true,
    },
  },

  env: {
    es6: true,
  },

  rules: {

    // Possible Errors (http://eslint.org/docs/rules/#possible-errors)
    'no-cond-assign': 'error',
    'no-console': 'warn',
    'no-constant-condition': 'error',
    'no-control-regex': 'error',
    'no-debugger': 'warn',
    'no-dupe-args': 'error',
    'no-dupe-keys': 'error',
    'no-duplicate-case': 'error',
    'no-empty-character-class': 'error',
    'no-empty': 'error',
    'no-ex-assign': 'error',
    'no-extra-boolean-cast': 'error',
    'no-extra-parens': 'error',
    'no-extra-semi': 'error',
    'no-func-assign': 'error',
    'no-inner-declarations': 'error',
    'no-invalid-regexp': 'error',
    'no-irregular-whitespace': 'error',
    'no-obj-calls': 'error',
    'no-prototype-builtins': 'error',
    'no-regex-spaces': 'error',
    'no-sparse-arrays': 'error',
    'no-template-curly-in-string': 'error',
    'no-unexpected-multiline': 'error',
    'no-unreachable': 'error',
    'no-unsafe-finally': 'error',
    'no-unsafe-negation': 'error',
    'use-isnan': 'error',
    'valid-jsdoc': 'error',
    'valid-typeof': 'error',

    // Best Practices (http://eslint.org/docs/rules/#best-practices)
    'accessor-pairs': 'error',
    'array-callback-return': 'error',
    'block-scoped-var': 'error',
    'class-methods-use-this': 'error',
    'complexity': 'off', // to deal with on a per-project basis, in the code coverage tool
    'consistent-return': 'error',
    'curly': 'error',
    'default-case': 'error',
    'dot-location': ['error', 'property'],
    'dot-notation': 'error',
    'eqeqeq': 'error',
    'guard-for-in': 'error',
    'no-caller': 'error',
    'no-case-declarations': 'error',
    'no-div-regex': 'error',
    'no-else-return': 'error',
    'no-empty-function': 'error',
    'no-empty-pattern': 'error',
    'no-eq-null': 'error',
    'no-eval': 'error',
    'no-extend-native': 'error',
    'no-extra-bind': 'error',
    'no-extra-label': 'error',
    'no-fallthrough': 'error',
    'no-floating-decimal': 'error',
    'no-global-assign': 'error',
    'no-implicit-coercion': 'error',
    'no-implicit-globals': 'error',
    'no-implied-eval': 'error',
    'no-invalid-this': 'error',
    'no-iterator': 'error',
    'no-labels': 'error',
    'no-lone-blocks': 'error',
    'no-loop-func': 'error',
    'no-magic-numbers': 'error',
    'no-multi-spaces': 'error',
    'no-multi-str': 'error',
    'no-new-func': 'error',
    'no-new-wrappers': 'error',
    'no-new': 'error',
    'no-octal-escape': 'error',
    'no-octal': 'error',
    'no-param-reassign': 'error',
    'no-proto': 'error',
    'no-redeclare': 'error',
    'no-return-assign': 'error',
    'no-self-assign': 'error',
    'no-self-compare': 'error',
    'no-sequences': 'error',
    'no-throw-literal': 'error',
    'no-unmodified-loop-condition': 'error',
    'no-unused-expressions': 'error',
    'no-unused-labels': 'error',
    'no-useless-call': 'error',
    'no-useless-concat': 'error',
    'no-useless-escape': 'error',
    'no-void': 'error',
    'no-warning-comments': ['warn', { location: 'anywhere' }],
    'no-with': 'error',
    'radix': 'error',
    'vars-on-top': 'error',
    'wrap-iife': 'error',
    'yoda': 'error',

    // Strict Mode (http://eslint.org/docs/rules/#strict-mode)
    'strict': ['error', 'never'],

    // Variables (http://eslint.org/docs/rules/#variables)
    'init-declarations': 'error',
    'no-catch-shadow': 'error',
    'no-delete-var': 'error',
    'no-label-var': 'error',
    'no-restricted-globals': 'error',
    'no-shadow-restricted-names': 'error',
    'no-shadow': 'error',
    'no-undef-init': 'error',
    'no-undef': 'error',
    'no-undefined': 'error',
    'no-unused-vars': 'error',
    'no-use-before-define': 'off', // function hoisting is good for readability

    // Stylistic Issues (http://eslint.org/docs/rules/#stylistic-issues)
    'array-bracket-spacing': 'off', // babel/array-bracket-spacing
    'block-spacing': 'error',
    'brace-style': 'error',
    'camelcase': 'error',
    'comma-dangle': ['error', 'always-multiline'],
    'comma-spacing': 'error',
    'comma-style': 'error',
    'computed-property-spacing': 'error',
    'consistent-this': 'error',
    'eol-last': 'error',
    'func-call-spacing': 'error',
    'func-names': 'error',
    'func-style': 'error',
    'id-blacklist': 'off', // forbid short ids only, not from a list
    'id-length': 'error',
    'id-match': 'off', // do not whitelist ids from a regexp
    'indent': ['error', 2],
    'key-spacing': 'error',
    'keyword-spacing': 'error',
    'linebreak-style': 'error',
    'lines-around-comment': 'off', // decrease overall readability
    'max-depth': 'error',
    'max-len': ['error', { code: 120 }],
    'max-lines': 'error',
    'max-nested-callbacks': 'error',
    'max-params': 'error',
    'max-statements-per-line': 'error',
    'max-statements': 'error',
    'multiline-ternary': 'error',
    'new-cap': 'off', // babel/new-cap
    'new-parens': 'error',
    'newline-after-var': 'error',
    'newline-before-return': 'error',
    'newline-per-chained-call': 'error',
    'no-array-constructor': 'error',
    'no-bitwise': 'error',
    'no-continue': 'error',
    'no-inline-comments': 'off', // sometimes useful
    'no-lonely-if': 'error',
    'no-mixed-operators': 'error',
    'no-mixed-spaces-and-tabs': 'error',
    'no-multiple-empty-lines': 'error',
    'no-negated-condition': 'error',
    'no-nested-ternary': 'error',
    'no-new-object': 'error',
    'no-plusplus': 'error',
    'no-restricted-syntax': 'off', // do not restrict syntax
    'no-tabs': 'error',
    'no-ternary': 'off', // allow ternary
    'no-trailing-spaces': 'error',
    'no-underscore-dangle': 'error',
    'no-unneeded-ternary': 'error',
    'no-whitespace-before-property': 'error',
    'object-curly-newline': 'off', // do not restrict newlines in objects
    'object-curly-spacing': 'off', // babel/object-curly-spacing
    'object-property-newline': 'error',
    'one-var-declaration-per-line': 'error',
    'one-var': 'error',
    'operator-assignment': 'error',
    'operator-linebreak': 'error',
    'padded-blocks': 'error',
    'quote-props': ['error', 'consistent-as-needed'],
    'quotes': ['error', 'single'],
    'require-jsdoc': 'error',
    'semi-spacing': 'error',
    'semi': ['error', 'never'],
    'sort-keys': 'off', // context sort > lexical sort
    'sort-vars': 'off', // context sort > lexical sort
    'space-before-blocks': 'error',
    'space-before-function-paren': ['error', 'never'],
    'space-in-parens': 'error',
    'space-infix-ops': 'error',
    'space-unary-ops': 'error',
    'spaced-comment': 'error',
    'unicode-bom': 'error',
    'wrap-regex': 'error',

    // ECMAScript 6 (http://eslint.org/docs/rules/#ecmascript-6)
    'arrow-body-style': 'error',
    'arrow-parens': 'off', // babel/arrow-parens
    'arrow-spacing': 'error',
    'constructor-super': 'error',
    'generator-star-spacing': 'off', // babel/generator-star-spacing
    'no-class-assign': 'error',
    'no-confusing-arrow': 'error',
    'no-const-assign': 'error',
    'no-dupe-class-members': 'error',
    'no-duplicate-imports': 'off', // import/no-duplicates
    'no-new-symbol': 'error',
    'no-restricted-imports': 'off', // do not restrict imports
    'no-this-before-super': 'error',
    'no-useless-computed-key': 'error',
    'no-useless-constructor': 'error',

    // eslint-plugin-babel (https://github.com/babel/eslint-plugin-babel)
    'babel/array-bracket-spacing': 'error',
    'babel/arrow-parens': ['error', 'always'],
    'babel/flow-object-type': 'error',
    'babel/func-params-comma-dangle': 'error',
    'babel/generator-star-spacing': 'error',
    'babel/new-cap': 'error',
    'babel/no-await-in-loop': 'error',
    'babel/object-curly-spacing': ['error', 'always'],
    'babel/object-shorthand': 'error',

    // eslint-plugin-import (https://github.com/benmosher/eslint-plugin-import#rules)
    'import/default': 'error',
    'import/export': 'error',
    'import/extensions': 'error',
    'import/imports-first': 'error',
    'import/max-dependencies': 'off', // TODO: enable when pushed to npm
    'import/named': 'error',
    'import/namespace': 'error',
    'import/newline-after-import': 'error',
    'import/no-absolute-path': 'off', // TODO: enable when pushed to npm
    'import/no-amd': 'error',
    'import/no-deprecated': 'error',
    'import/no-duplicates': 'error',
    'import/no-extraneous-dependencies': 'error',
    'import/no-mutable-exports': 'error',
    'import/no-named-as-default': 'error',
    'import/no-named-as-default-member': 'error',
    'import/no-namespace': 'error',
    'import/no-restricted-paths': 'off', // do not restrict paths
    'import/no-unresolved': ['error', { commonjs: true }],
    'import/order': 'error',
    'import/prefer-default-export': 'error',

    // eslint-plugin-xo (https://github.com/sindresorhus/eslint-plugin-xo)
    'xo/catch-error-name': ['error', { name: 'error' }],
    'xo/explicit-length-check': 'off', // TODO: enable when pushed to npm
    'xo/filename-case': 'off', // might differ between utilities and files
    'xo/no-abusive-eslint-disable': 'error',
    'xo/throw-new-error': 'error',

  },

}

==> eslint-config-opinionated-1.4.0.tgz: package/index.js <==
/* eslint-disable max-lines, no-magic-numbers */

module.exports = {

  extends: [
    'eslint:all',
  ],

  plugins: [
    'babel',
    'import',
    'xo',
  ],

  parser: 'babel-eslint',
  parserOptions: {
    ecmaVersion: 7,
    sourceType: 'module',
    ecmaFeatures: {
      globalReturn: false,
      impliedStrict: true,
      jsx: true,
      experimentalObjectRestSpread: true,
    },
  },

  env: {
    es6: true,
  },

  rules: {

    // Possible Errors (http://eslint.org/docs/rules/#possible-errors)
    'no-cond-assign': 'error',
    'no-console': 'warn',
    'no-constant-condition': 'error',
    'no-control-regex': 'error',
    'no-debugger': 'warn',
    'no-dupe-args': 'error',
    'no-dupe-keys': 'error',
    'no-duplicate-case': 'error',
    'no-empty-character-class': 'error',
    'no-empty': 'error',
    'no-ex-assign': 'error',
    'no-extra-boolean-cast': 'error',
    'no-extra-parens': 'error',
    'no-extra-semi': 'error',
    'no-func-assign': 'error',
    'no-inner-declarations': 'error',
    'no-invalid-regexp': 'error',
    'no-irregular-whitespace': 'error',
    'no-obj-calls': 'error',
    'no-prototype-builtins': 'error',
    'no-regex-spaces': 'error',
    'no-sparse-arrays': 'error',
    'no-template-curly-in-string': 'error',
    'no-unexpected-multiline': 'error',
    'no-unreachable': 'error',
    'no-unsafe-finally': 'error',
    'no-unsafe-negation': 'error',
    'use-isnan': 'error',
    'valid-jsdoc': 'error',
    'valid-typeof': 'error',

    // Best Practices (http://eslint.org/docs/rules/#best-practices)
    'accessor-pairs': 'error',
    'array-callback-return': 'error',
    'block-scoped-var': 'error',
    'class-methods-use-this': 'error',
    'complexity': 'off', // to deal with on a per-project basis, in the code coverage tool
    'consistent-return': 'error',
    'curly': 'error',
    'default-case': 'error',
    'dot-location': ['error', 'property'],
    'dot-notation': 'error',
    'eqeqeq': 'error',
    'guard-for-in': 'error',
    'no-caller': 'error',
    'no-case-declarations': 'error',
    'no-div-regex': 'error',
    'no-else-return': 'error',
    'no-empty-function': 'error',
    'no-empty-pattern': 'error',
    'no-eq-null': 'error',
    'no-eval': 'error',
    'no-extend-native': 'error',
    'no-extra-bind': 'error',
    'no-extra-label': 'error',
    'no-fallthrough': 'error',
    'no-floating-decimal': 'error',
    'no-global-assign': 'error',
    'no-implicit-coercion': 'error',
    'no-implicit-globals': 'error',
    'no-implied-eval': 'error',
    'no-invalid-this': 'error',
    'no-iterator': 'error',
    'no-labels': 'error',
    'no-lone-blocks': 'error',
    'no-loop-func': 'error',
    'no-magic-numbers': 'error',
    'no-multi-spaces': 'error',
    'no-multi-str': 'error',
    'no-new-func': 'error',
    'no-new-wrappers': 'error',
    'no-new': 'error',
    'no-octal-escape': 'error',
    'no-octal': 'error',
    'no-param-reassign': 'error',
    'no-proto': 'error',
    'no-redeclare': 'error',
    'no-return-assign': 'error',
    'no-self-assign': 'error',
    'no-self-compare': 'error',
    'no-sequences': 'error',
    'no-throw-literal': 'error',
    'no-unmodified-loop-condition': 'error',
    'no-unused-expressions': 'error',
    'no-unused-labels': 'error',
    'no-useless-call': 'error',
    'no-useless-concat': 'error',
    'no-useless-escape': 'error',
    'no-void': 'error',
    'no-warning-comments': ['warn', { location: 'anywhere' }],
    'no-with': 'error',
    'radix': 'error',
    'vars-on-top': 'error',
    'wrap-iife': 'error',
    'yoda': 'error',

    // Strict Mode (http://eslint.org/docs/rules/#strict-mode)
    'strict': ['error', 'never'],

    // Variables (http://eslint.org/docs/rules/#variables)
    'init-declarations': 'error',
    'no-catch-shadow': 'error',
    'no-delete-var': 'error',
    'no-label-var': 'error',
    'no-restricted-globals': 'error',
    'no-shadow-restricted-names': 'error',
    'no-shadow': 'error',
    'no-undef-init': 'error',
    'no-undef': 'error',
    'no-undefined': 'error',
    'no-unused-vars': 'error',
    'no-use-before-define': 'off', // function hoisting is good for readability

    // Stylistic Issues (http://eslint.org/docs/rules/#stylistic-issues)
    'array-bracket-spacing': 'off', // babel/array-bracket-spacing
    'block-spacing': 'error',
    'brace-style': 'error',
    'camelcase': 'error',
    'comma-dangle': ['error', 'always-multiline'],
    'comma-spacing': 'error',
    'comma-style': 'error',
    'computed-property-spacing': 'error',
    'consistent-this': 'error',
    'eol-last': 'error',
    'func-call-spacing': 'error',
    'func-names': 'error',
    'func-style': ['error', 'expression', { allowArrowFunctions: true }],
    'id-blacklist': 'off', // forbid short ids only, not from a list
    'id-length': 'error',
    'id-match': 'off', // do not whitelist ids from a regexp
    'indent': ['error', 2],
    'key-spacing': 'error',
    'keyword-spacing': 'error',
    'linebreak-style': 'error',
    'lines-around-comment': 'off', // decrease overall readability
    'max-depth': 'error',
    'max-len': ['error', { code: 120 }],
    'max-lines': ['error', { max: 125 }],
    'max-nested-callbacks': 'error',
    'max-params': 'error',
    'max-statements-per-line': 'error',
    'max-statements': 'error',
    'multiline-ternary': 'error',
    'new-cap': 'off', // babel/new-cap
    'new-parens': 'error',
    'newline-after-var': 'error',
    'newline-before-return': 'error',
    'newline-per-chained-call': 'error',
    'no-array-constructor': 'error',
    'no-bitwise': 'error',
    'no-continue': 'error',
    'no-inline-comments': 'off', // sometimes useful
    'no-lonely-if': 'error',
    'no-mixed-operators': 'error',
    'no-mixed-spaces-and-tabs': 'error',
    'no-multiple-empty-lines': 'error',
    'no-negated-condition': 'error',
    'no-nested-ternary': 'error',
    'no-new-object': 'error',
    'no-plusplus': 'error',
    'no-restricted-syntax': 'off', // do not restrict syntax
    'no-tabs': 'error',
    'no-ternary': 'off', // allow ternary
    'no-trailing-spaces': 'error',
    'no-underscore-dangle': 'error',
    'no-unneeded-ternary': 'error',
    'no-whitespace-before-property': 'error',
    'object-curly-newline': 'off', // do not restrict newlines in objects
    'object-curly-spacing': 'off', // babel/object-curly-spacing
    'object-property-newline': 'error',
    'one-var-declaration-per-line': 'error',
    'one-var': ['error', 'never'],
    'operator-assignment': 'error',
    'operator-linebreak': 'error',
    'padded-blocks': ['error', 'never'],
    'quote-props': ['error', 'consistent-as-needed'],
    'quotes': ['error', 'single'],
    'require-jsdoc': 'error',
    'semi-spacing': 'error',
    'semi': ['error', 'never'],
    'sort-keys': 'off', // context sort > lexical sort
    'sort-vars': 'off', // context sort > lexical sort
    'space-before-blocks': 'error',
    'space-before-function-paren': ['error', 'never'],
    'space-in-parens': 'error',
    'space-infix-ops': 'error',
    'space-unary-ops': 'error',
    'spaced-comment': 'error',
    'unicode-bom': 'error',
    'wrap-regex': 'error',

    // ECMAScript 6 (http://eslint.org/docs/rules/#ecmascript-6)
    'arrow-body-style': 'error',
    'arrow-parens': 'off', // babel/arrow-parens
    'arrow-spacing': 'error',
    'constructor-super': 'error',
    'generator-star-spacing': 'off', // babel/generator-star-spacing
    'no-class-assign': 'error',
    'no-confusing-arrow': 'error',
    'no-const-assign': 'error',
    'no-dupe-class-members': 'error',
    'no-duplicate-imports': 'off', // import/no-duplicates
    'no-new-symbol': 'error',
    'no-restricted-imports': 'off', // do not restrict imports
    'no-this-before-super': 'error',
    'no-useless-computed-key': 'error',
    'no-useless-constructor': 'error',
    'no-useless-rename': 'error',
    'no-var': 'error',
    'object-shorthand': 'off', // babel/object-shorthand
    'prefer-arrow-callback': ['error', { allowNamedFunctions: true }],
    'prefer-const': 'error',
    'prefer-reflect': 'error',
    'prefer-rest-params': 'error',
    'prefer-spread': 'error',
    'prefer-template': 'error',
    'require-yield': 'error',
    'rest-spread-spacing': 'error',
    'sort-imports': 'off', // import/order
    'symbol-description': 'error',
    'template-curly-spacing': 'error',
    'yield-star-spacing': 'error',

    // eslint-plugin-babel (https://github.com/babel/eslint-plugin-babel)
    'babel/array-bracket-spacing': 'error',
    'babel/arrow-parens': ['error', 'always'],
    'babel/flow-object-type': 'error',
    'babel/func-params-comma-dangle': 'error',
    'babel/generator-star-spacing': 'error',
    'babel/new-cap': 'error',
    'babel/no-await-in-loop': 'error',
    'babel/object-curly-spacing': ['error', 'always'],
    'babel/object-shorthand': 'error',

    // eslint-plugin-import (https://github.com/benmosher/eslint-plugin-import#rules)
    'import/default': 'error',
    'import/export': 'error',
    'import/extensions': 'error',
    'import/imports-first': 'error',
    'import/max-dependencies': 'off', // TODO: enable when pushed to npm
    'import/named': 'error',
    'import/namespace': 'error',
    'import/newline-after-import': 'error',
    'import/no-absolute-path': 'off', // TODO: enable when pushed to npm
    'import/no-amd': 'error',
    'import/no-deprecated': 'error',
    'import/no-duplicates': 'error',
    'import/no-extraneous-dependencies': 'error',
    'import/no-mutable-exports': 'error',
    'import/no-named-as-default': 'error',
    'import/no-named-as-default-member': 'error',
    'import/no-namespace': 'error',
    'import/no-restricted-paths': 'off', // do not restrict paths
    'import/no-unresolved': ['error', { commonjs: true }],
    'import/order': 'error',
    'import/prefer-default-export': 'error',

    // eslint-plugin-xo (https://github.com/sindresorhus/eslint-plugin-xo)
    'xo/catch-error-name': ['error', { name: 'error' }],
    'xo/explicit-length-check': 'off', // TODO: enable when pushed to npm
    'xo/filename-case': 'off', // might differ between utilities and files
    'xo/no-abusive-eslint-disable': 'error',
    'xo/throw-new-error': 'error',

  },

}
